##  Related Resources
  * [Categorizing Applications Using the Gartner® TIME Framework with Tags](https://help.sap.com/docs/leanix/ea/updating-tag-related-to-time-model "https://help.sap.com/docs/leanix/ea/updating-tag-related-to-time-model")
